========================
``psyclone.tests.psyir``
========================

.. automodule:: psyclone.tests.psyir

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.tests.psyir.backend
   psyclone.tests.psyir.conftest
   psyclone.tests.psyir.frontend

.. currentmodule:: psyclone.tests.psyir
